---
title: <span class="badge builder"></span> Role
---
# <span class="badge builder"></span> Role

## Constructor

```python
Role()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> role.Role
```

### <span class="badge object-method"></span> description

Role description

```python
def description(description: str) -> typing.Self
```

### <span class="badge object-method"></span> display_name

Optional display

```python
def display_name(display_name: str) -> typing.Self
```

### <span class="badge object-method"></span> group_name

Name of the team.

```python
def group_name(group_name: str) -> typing.Self
```

### <span class="badge object-method"></span> hidden

Do not show this role

```python
def hidden(hidden: bool) -> typing.Self
```

### <span class="badge object-method"></span> name

The role identifier `managed:builtins:editor:permissions`

```python
def name(name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Role](./object-Role.md)
